@@ -1,13 +1,12 @@
 // =====================================================================
-//  $Id: rs01OFFmsec.cc,v 1.1 2003/08/17 20:15:37 goiwai Exp $
-//  $Name: CLDAQ-1-08-01 $
+//  $Id: rs01OFFmsec.cc,v 1.2 2003/09/17 10:00:08 goiwai Exp $
+//  $Name: CLDAQ-1-08-02 $
 //
 //  $Log: rs01OFFmsec.cc,v $
-//  Revision 1.1  2003/08/17 20:15:37  goiwai
-//  OFFxxx.cc Ȥ̾ΤĤե̾ rs01OFFxxx.cc ѹޤ.
+//  Revision 1.2  2003/09/17 10:00:08  goiwai
+//  ľΥ٥Ȥηв֤ץåȤޤ.
+//  ͥˤĤƥץåȤޤ.ӥ10ߥäǤ.
 //
-//  Revision 1.2  2003/07/30 16:14:40  goiwai
-//  ե˥ߥåȥĤ뤳Ȥˤޤ.
 //
 // =====================================================================
 #include "TDataRecord.hh"
@@ -20,13 +19,13 @@
 
 static const Tstring rcpath = "rs01setup";
 static const Tint npin = 32;
-// static Tint pinpos[ npin ] = {
-//            3,  4, 5,   6,  7,
-//       10, 11, 12, 13, 14, 15, 16,
-//   17, 18, 19, 20, 21, 22, 23, 24,
-//       26, 27, 28, 29, 30, 31, 32,
-//           35, 36, 37, 38, 39
-// };
+static Tint pinpos[ npin ] = {
+           3,  4, 5,   6,  7,
+       10, 11, 12, 13, 14, 15, 16,
+   17, 18, 19, 20, 21, 22, 23, 24,
+       26, 27, 28, 29, 30, 31, 32,
+           35, 36, 37, 38, 39
+};
 
 TInputObjectFile* ifile = 0;
 TEnvironmentVariableTable* envtable = 0;
@@ -37,10 +36,10 @@ Tint elapsed[ npin ];
 //
 TApplication* theApplication = 0;
 TCanvas* CVvdc = 0;
-static const Tint nx = 3;
-static const Tint ny = 3;
+static const Tint nx = 8;
+static const Tint ny = 5;
 static const Tint npadvdc = nx * ny;
-TH1D* H1Dvdc[ npin ];
+TH1D** H1Dvdc;
 
 Tstring htvdc[ npin ];
 Tstring hnamevdc[ npin ];
@@ -52,19 +51,12 @@ static Tvoid initialize( Tint argc, Tchar** argv );
 static Tvoid event();
 static Tvoid runbegin();
 static Tvoid runend();
-static Tvoid sizezero();
 
 int main( int argc, char** argv, char** envv )
 {
   initialize( argc, argv );
 
-  while ( 1 ) {
-    Tint datasize = ifile -> Read( record );
-    if ( datasize == 0 ) {
-      sizezero();
-      continue;
-    }
-
+  while ( ifile -> Read( record ) ) {
     Tstring recid = record.GetID();
     if ( recid == "RUN BEGIN" ) {
       runbegin();
@@ -81,7 +73,7 @@ int main( int argc, char** argv, char** envv )
     gSystem -> ProcessEvents();
   }
 
-  theApplication -> Run();
+  theApplication -> Terminate();
   return( 0 );
 }
 
@@ -90,7 +82,7 @@ Tvoid initialize( Tint argc, Tchar** argv )
   if ( argc != 2 ) {
     Tcerr << "usage: " << argv[ 0 ] << " <run#>" << Tendl;
     exit( -1 );
-  } 
+  }
 
   Tint runid = (Tint)strtol( argv[ 1 ], 0, 0 );
   Tstring runidstr = itostr( runid );
@@ -101,14 +93,14 @@ Tvoid initialize( Tint argc, Tchar** argv )
   fpath = recpath + Tslash + rechead + runidstr + ".drec";
   ifile = new TInputObjectFile( fpath );
 
-  Tstring rootdir = envtable -> GetEnvironmentValue( "RS01_ROOTFILE_DIR" );
-  rootf = rootdir + Tslash + rechead + runidstr + "OFFmsec.root";
-  Tstring macrodir = envtable -> GetEnvironmentValue( "RS01_ROOTFILE_DIR" );
-  macrof = macrodir + Tslash + rechead + runidstr + "OFFmsec.C";
-  Tstring gifdir = envtable -> GetEnvironmentValue( "RS01_FIGURE_DIR" );
-  giff = gifdir + Tslash + rechead + runidstr + "OFFmsec.gif";
-  Tstring psdir = envtable -> GetEnvironmentValue( "RS01_FIGURE_DIR" );
-  psf = psdir + Tslash + rechead + runidstr + "OFFmsec.ps";
+  //Tstring rootdir = envtable -> GetEnvironmentValue( "RS01_ROOTFILE_DIR" );
+  rootf = rechead + runidstr + "msec.root";
+  //Tstring macrodir = envtable -> GetEnvironmentValue( "RS01_ROOTFILE_DIR" );
+  macrof = rechead + runidstr + "msec.C";
+  //Tstring gifdir = envtable -> GetEnvironmentValue( "RS01_FIGURE_DIR" );
+  giff = rechead + runidstr + "msec.gif";
+  //Tstring psdir = envtable -> GetEnvironmentValue( "RS01_FIGURE_DIR" );
+  psf = rechead + runidstr + "msec.ps";
 
   modperiod = envtable -> GetIntegerValue( "RS01_UPDATE_PERIOD" );
   enableoverwrite = (Tbool)envtable -> GetIntegerValue( "RS01_OVERWRITE_ENABLE" );
@@ -117,51 +109,35 @@ Tvoid initialize( Tint argc, Tchar** argv )
 
 
   theApplication = rootinit();
-  //TGaxis::SetMaxDigits( 1 );
+  TGaxis::SetMaxDigits( 2 );
 
 
-  //  Х
-  CVvdc = new TCanvas( "CVmsec", "Elapsed Time by Event", 960, 720 );
+  // Ű VS  Х
+  CVvdc = new TCanvas( "CVvdc", "Elapsed Time VS Time", 960, 720 );
   CVvdc -> ToggleEventStatus();
-  CVvdc -> Divide( 3, 3 );
+  CVvdc -> Divide( nx, ny );
 
 
   // Ű VS ֤ν
+  H1Dvdc = new TH1D*[npin];
   for ( Tint ch = 0; ch < npin; ch ++ ) {
     htvdc[ ch ] = "Channel: " + itostr( ch, 2 ) + ", Run ID: " + runidstr;
-    hnamevdc[ ch ] = "H1Dvdc" + itostr( ch, 2 );
+    hnamevdc[ ch ] = "H1Dmsec" + itostr( ch, 2 );
 
     H1Dvdc[ ch ] = 
-      new TH1D( hnamevdc[ ch ].c_str(), htvdc[ ch ].c_str(), 100, 4000.0, 8000.0 );
-
+      new TH1D( hnamevdc[ ch ].c_str(), htvdc[ ch ].c_str(), 800, 0.0, 8000.0 );
+    
     H1Dvdc[ ch ] -> GetXaxis() -> SetTitle( "Elapsed Time (msec)" );
     H1Dvdc[ ch ] -> GetXaxis() -> CenterTitle();
     H1Dvdc[ ch ] -> GetXaxis() -> SetNoExponent();
 
     H1Dvdc[ ch ] -> GetYaxis() -> SetTitle( "Counts" );
     H1Dvdc[ ch ] -> GetYaxis() -> CenterTitle();
-    H1Dvdc[ ch ] -> GetYaxis() -> SetNoExponent();
-  }
+    //H1Dvdc[ ch ] -> GetYaxis() -> SetNoExponent();
 
-  //ɽΤ 7,8,9 15,16,17 22,23,24
-  CVvdc -> cd( 1 );
-  H1Dvdc[ 7 ] -> Draw();
-  CVvdc -> cd( 2 );
-  H1Dvdc[ 8 ] -> Draw();
-  CVvdc -> cd( 3 );
-  H1Dvdc[ 9 ] -> Draw();
-  CVvdc -> cd( 4 );
-  H1Dvdc[ 15 ] -> Draw();
-  CVvdc -> cd( 5 );
-  H1Dvdc[ 16 ] -> Draw();
-  CVvdc -> cd( 6 );
-  H1Dvdc[ 17 ] -> Draw();
-  CVvdc -> cd( 7 );
-  H1Dvdc[ 22 ] -> Draw();
-  CVvdc -> cd( 8 );
-  H1Dvdc[ 23 ] -> Draw();
-  CVvdc -> cd( 9 );
-  H1Dvdc[ 24 ] -> Draw();
+    CVvdc -> cd( pinpos[ ch ] );
+    H1Dvdc[ ch ] -> Draw();
+  }
 
   return;
 }
@@ -176,6 +152,7 @@ Tvoid event()
   }
 
 
+
   // update
   element = record[ 0 ][ 0 ][ 0 ];
   Tint eventid;
@@ -205,30 +182,17 @@ Tvoid runend()
 
   // printout
   CVvdc -> cd();
-  if ( !isexist( rootf ) || enableoverwrite ) {
-    CVvdc -> Print( rootf.c_str() );
-  }
-  if ( !isexist( macrof ) || enableoverwrite ) {
-    CVvdc -> Print( macrof.c_str() );
-  }
-  if ( !isexist( giff ) || enableoverwrite ) {
-    CVvdc -> Print( giff.c_str() );
-  }
-  if ( !isexist( psf ) || enableoverwrite ) {
-    CVvdc -> Print( psf.c_str() );
-    if ( autoprint ) {
-      Tstring exec = "lpr " + psf;
-      system( exec.c_str() );
-    }
+
+  TFile* file = new TFile( rootf.c_str(), "RECREATE", "VDC VIEW OFFLINE" );
+  for ( Tint ch = 0; ch < npin; ch ++ ) {
+    H1Dvdc[ ch ] -> Write();
   }
+  CVvdc -> Write();
+  file -> Close();
+
+
+  CVvdc -> Print( giff.c_str() );
+  CVvdc -> Print( psf.c_str() );
 
   return;
 }
-
-Tvoid sizezero()
-{
-  ifile -> SetOffset( ifile -> GetTotalDataSize(), SEEK_SET );
-  usleep( 1000*1000 );
-  gSystem -> ProcessEvents();
-  return;
-}
